# tablesorter 2.0-dev demo, multi column sorting

To select more then one column to sort by, hold down your shift key and press the "headers". Pressing a all ready sorted column while holding down shift will reverse the order.

Releasing the shift key and pressing a column will result in a one column sort.

Not big enough? Add 500 random rows of data (can be clicked many times, more then a 1000 rows can be slow)

Name | Major | Sex | English | Japanese | Calculus | Geometry
--- | --- | --- | --- | --- | --- | ---
Name | Major | Sex | English | Japanese | Calculus | Geometry
Student01 | Languages | male | 80 | 100'70,00.00 | 75.00 | 0
Student02 | Mathematics | male | 90 | 88 | 100 | 90
Student03 | Languages | female | 85 | 95 | 80 | 85
Student04 | Languages | male | 60 | 55 | 100 | 100